assert_always_or_unreachable

Macro assert_always_or_unreachable 

macro_rules! assert_always_or_unreachable {
    ($condition:expr, $message:expr) => { ... };
}
Assert that a condition is always true when reached, but the code path need not be reached. Does not panic if never evaluated.

Does not panic on failure — records the violation and logs at ERROR level.