assert_sometimes

Macro assert_sometimes 

macro_rules! assert_sometimes {
    ($condition:expr, $message:expr) => { ... };
}
Assert a condition that should sometimes be true, tracking stats and triggering exploration.

Does not panic. On first success, triggers a fork to explore alternate timelines.