Module providers

Module providers 

Provider implementations for simulation. Provider implementations for simulation.

This module provides simulation-specific implementations of the provider traits defined in moonpool-core.

Structs

SimProviders
Simulation providers bundle for deterministic testing.
SimRandomProvider
Random provider for simulation that uses the thread-local deterministic RNG.
SimTaskProvider
Task provider that spawns onto the deterministic executor driving the current simulation iteration.
SimTimeProvider
Simulation time provider that integrates with SimWorld.