Module runner

Module runner 

Simulation runner and orchestration framework. Simulation runner and orchestration framework.

This module provides the infrastructure for running simulation experiments, collecting metrics, and generating comprehensive reports.

Submodules

  • builder - SimulationBuilder for configuring experiments
  • report - SimulationMetrics and SimulationReport types
  • topology - WorkloadTopology and workload configuration
  • orchestrator - Internal workload orchestration
  • tokio - TokioRunner for real-world execution

Re-exports

pub use builder::ClientId;
pub use builder::WorkloadCount;
pub use builder::IterationControl;
pub use builder::SimulationBuilder;
pub use context::SimContext;
pub use fault_injector::FaultContext;
pub use fault_injector::FaultInjector;
pub use fault_injector::PhaseConfig;
pub use process::Attrition;
pub use process::Process;
pub use process::RebootKind;
pub use report::SimulationMetrics;
pub use report::SimulationReport;
pub use tags::ProcessTags;
pub use tags::TagRegistry;
pub use tokio::TokioReport;
pub use tokio::TokioRunner;
pub use topology::WorkloadTopology;
pub use workload::Workload;

Modules

builder
Simulation builder pattern for configuring and running experiments.
context
Simulation context for workloads.
display
Colored terminal display for simulation reports.
fault_injector
Fault injection for simulation chaos testing.
process
Process trait and reboot types for simulation testing.
report
Simulation metrics and reporting.
tags
Tag-based topology for process distribution and fault targeting.
tokio
Tokio-based runner for executing workloads with real networking and timing.
topology
Workload and process topology configuration.
workload
Workload trait for simulation testing.