Module display

Module display 

Colored terminal display for simulation reports.

Provides rich, colorized output for TTY stderr. Falls back to the plain Display impl when stderr is not a terminal or NO_COLOR is set.

Functions

eprint_report
Print the simulation report to stderr with colors if supported.