WeakSimWorld

Struct WeakSimWorld 

pub struct WeakSimWorld { /* private fields */ }
A weak reference to a simulation world.

This provides handle-based access to the simulation without holding a strong reference that would prevent cleanup.

Implementations

Source

impl WeakSimWorld

pub fn upgrade(&self) -> SimulationResult<SimWorld>

Attempts to upgrade this weak reference to a strong reference.

Errors

Returns an error if the operation is rejected by the simulator (for example, the simulation has not been started).

pub fn current_time(&self) -> SimulationResult<Duration>

Returns the current simulation time.

Errors

Returns an error if the simulation has been dropped.

pub fn now(&self) -> SimulationResult<Duration>

Returns the exact simulation time (equivalent to FDB’s now()).

Errors

Returns an error if the simulation has been dropped.

pub fn timer(&self) -> SimulationResult<Duration>

Returns the drifted timer time (equivalent to FDB’s timer()).

Errors

Returns an error if the simulation has been dropped.

pub fn schedule_event( &self, event: Event, delay: Duration, ) -> SimulationResult<()>

Schedules an event to execute after the specified delay.

Errors

Returns an error if the simulation has been dropped.

pub fn schedule_event_at( &self, event: Event, time: Duration, ) -> SimulationResult<()>

Schedules an event to execute at the specified absolute time.

Errors

Returns an error if the simulation has been dropped.

pub fn read_from_connection( &self, connection_id: ConnectionId, buf: &mut [u8], ) -> SimulationResult<usize>

Read data from connection’s receive buffer.

Errors

Returns an error if the simulation has been dropped or the underlying operation is rejected by the simulator.

pub fn write_to_connection( &self, connection_id: ConnectionId, data: &[u8], ) -> SimulationResult<()>

Write data to connection’s receive buffer.

Errors

Returns an error if the simulation has been dropped or the underlying operation is rejected by the simulator.

pub fn buffer_send( &self, connection_id: ConnectionId, data: Vec<u8>, ) -> SimulationResult<()>

Buffer data for ordered sending on a connection.

Errors

Returns an error if the simulation has been dropped or the underlying operation is rejected by the simulator.

pub fn network_provider(&self) -> SimulationResult<SimNetworkProvider>

Get a network provider for the simulation.

Errors

Returns an error if the simulation has been dropped.

pub fn time_provider(&self) -> SimulationResult<SimTimeProvider>

Get a time provider for the simulation.

Errors

Returns an error if the simulation has been dropped.

pub fn sleep(&self, duration: Duration) -> SimulationResult<SleepFuture>

Sleep for the specified duration in simulation time.

Errors

Returns an error if the simulation has been dropped.

pub fn with_network_config<F, R>(&self, f: F) -> SimulationResult<R>
where F: FnOnce(&NetworkConfiguration) -> R,

Access network configuration for latency calculations.

Errors

Returns an error if the operation is rejected by the simulator (for example, the simulation has not been started).