StorageOperation

Enum StorageOperation 

pub enum StorageOperation {
    ReadComplete {
        len: u32,
    },
    WriteComplete {
        len: u32,
    },
    SyncComplete,
    OpenComplete,
    SetLenComplete {
        new_len: u64,
    },
}
Storage operations that can be scheduled in the simulation.

Unlike network operations which model data delivery, storage operations model the completion of I/O requests. Each operation represents a pending I/O that completes at the scheduled time.

Variants



ReadComplete

Read operation completed.

The data has been read from storage and is ready to return to the caller. Faults (if any) are applied when processing.

Fields

len: u32

Number of bytes read



WriteComplete

Write operation completed.

The data has been accepted by the storage layer. Note that without a sync, this data may be lost on crash.

Fields

len: u32

Number of bytes written



SyncComplete

Sync operation completed.

All previously written data is now durable. May fail with sync_failure_probability.



OpenComplete

File open operation completed.



SetLenComplete

File truncate/extend operation completed.

Fields

new_len: u64

New file length