macro_rules! assert_always_or_unreachable {
($condition:expr, $message:expr) => { ... };
}Expand description
Assert that a condition is always true when reached, but the code path need not be reached. Does not panic if never evaluated.
Does not panic on failure — records the violation and logs at ERROR level.