pub fn eprint_report(report: &SimulationReport)Expand description
Print the simulation report to stderr with colors if supported.
Falls back to the plain Display impl when stderr is not a terminal
or the NO_COLOR environment variable is set.
pub fn eprint_report(report: &SimulationReport)Print the simulation report to stderr with colors if supported.
Falls back to the plain Display impl when stderr is not a terminal
or the NO_COLOR environment variable is set.