pub struct ExplorationReport {
pub total_timelines: u64,
pub fork_points: u64,
pub bugs_found: u64,
pub bug_recipes: Vec<BugRecipe>,
pub energy_remaining: i64,
pub realloc_pool_remaining: i64,
pub coverage_bits: u32,
pub coverage_total: u32,
}Expand description
Report from fork-based exploration.
Fields
total_timelines: u64Total timelines explored across all forks.
fork_points: u64Total fork points triggered.
bugs_found: u64Number of bugs found (children exiting with code 42).
bug_recipes: Vec<BugRecipe>Bug recipes captured during exploration (one per seed that found bugs).
energy_remaining: i64Remaining global energy after exploration.
realloc_pool_remaining: i64Energy in the reallocation pool.
coverage_bits: u32Number of bits set in the explored coverage map.
coverage_total: u32Total number of bits in the coverage map (8192).